@@ -343,7 +343,7 @@ class H264VideoConfiguration(VideoConfiguration):
         # type: () -> PresetConfiguration
         """Gets the preset_configuration of this H264VideoConfiguration.
 
-        Use a set of well defined configurations preset to support certain use cases. Can be overwritten with more specific values.
+        Choose from a set of preset configurations tailored for common use cases. Check out [H264 Presets](https://bitmovin.com/docs/encoding/tutorials/h264-presets) to see which values get applied by each preset. Explicitly setting a property to a different value will override the preset's value for that property.
 
         :return: The preset_configuration of this H264VideoConfiguration.
         :rtype: PresetConfiguration
@@ -355,7 +355,7 @@ class H264VideoConfiguration(VideoConfiguration):
         # type: (PresetConfiguration) -> None
         """Sets the preset_configuration of this H264VideoConfiguration.
 
-        Use a set of well defined configurations preset to support certain use cases. Can be overwritten with more specific values.
+        Choose from a set of preset configurations tailored for common use cases. Check out [H264 Presets](https://bitmovin.com/docs/encoding/tutorials/h264-presets) to see which values get applied by each preset. Explicitly setting a property to a different value will override the preset's value for that property.
 
         :param preset_configuration: The preset_configuration of this H264VideoConfiguration.
         :type: PresetConfiguration
